==> igniteui-react-charts-16.6.4.tgz: package/ES5/igr-category-tool-tip-layer.js <==
import * as tslib_1 from "tslib";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { CategoryToolTipLayer } from "./CategoryToolTipLayer";
import { ensureBool } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents an annotation layer that displays grouped tooltips for series that use a category axis.
*/
var IgrCategoryToolTipLayer = /** @class */ (function (_super) {
    tslib_1.__extends(IgrCategoryToolTipLayer, _super);
    function IgrCategoryToolTipLayer(props) {
        return _super.call(this, props) || this;
    }
    IgrCategoryToolTipLayer.prototype.createImplementation = function () {
        return new CategoryToolTipLayer();
    };
    Object.defineProperty(IgrCategoryToolTipLayer.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryToolTipLayer.prototype, "isDefaultTooltipBehaviorDisabled", {
        /**
         * Gets whether the default tooltip behaviors for the chart are disabled if this layer is present.
        */
        get: function () {
            return this.i.cn;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryToolTipLayer.prototype, "useInterpolation", {
        /**
         * Gets or sets whether to use value interpolation when drawing the tooltips.
        */
        get: function () {
            return this.i.mx;
        },
        set: function (v) {
            this.i.mx = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    return IgrCategoryToolTipLayer;
}(IgrAnnotationLayer));
export { IgrCategoryToolTipLayer };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-category-tool-tip-layer.js <==
import * as tslib_1 from "tslib";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { CategoryToolTipLayer } from "./CategoryToolTipLayer";
import { ensureBool } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents an annotation layer that displays grouped tooltips for series that use a category axis.
*/
var IgrCategoryToolTipLayer = /** @class */ (function (_super) {
    tslib_1.__extends(IgrCategoryToolTipLayer, _super);
    function IgrCategoryToolTipLayer(props) {
        return _super.call(this, props) || this;
    }
    IgrCategoryToolTipLayer.prototype.createImplementation = function () {
        return new CategoryToolTipLayer();
    };
    Object.defineProperty(IgrCategoryToolTipLayer.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryToolTipLayer.prototype, "isDefaultTooltipBehaviorDisabled", {
        /**
         * Gets whether the default tooltip behaviors for the chart are disabled if this layer is present.
        */
        get: function () {
            return this.i.cn;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryToolTipLayer.prototype, "useInterpolation", {
        /**
         * Gets or sets whether to use value interpolation when drawing the tooltips.
        */
        get: function () {
            return this.i.mz;
        },
        set: function (v) {
            this.i.mz = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    return IgrCategoryToolTipLayer;
}(IgrAnnotationLayer));
export { IgrCategoryToolTipLayer };
